/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
import * as beetSolana from '@metaplex-foundation/beet-solana';
import { Key } from '../types/Key';
import { EscrowConstraint } from '../types/EscrowConstraint';
import { RoyaltyInstruction } from '../types/RoyaltyInstruction';
export type EscrowConstraintModelArgs = {
    key: Key;
    creator: web3.PublicKey;
    name: string;
    constraints: Map<string, EscrowConstraint>;
    updateAuthority: web3.PublicKey;
    count: beet.bignum;
    schemaUri: beet.COption<string>;
    royalties: Map<RoyaltyInstruction, Partial<beet.bignum>>;
    royaltyBalance: beet.bignum;
    padding: number[];
};
export declare class EscrowConstraintModel implements EscrowConstraintModelArgs {
    readonly key: Key;
    readonly creator: web3.PublicKey;
    readonly name: string;
    readonly constraints: Map<string, EscrowConstraint>;
    readonly updateAuthority: web3.PublicKey;
    readonly count: beet.bignum;
    readonly schemaUri: beet.COption<string>;
    readonly royalties: Map<RoyaltyInstruction, Partial<beet.bignum>>;
    readonly royaltyBalance: beet.bignum;
    readonly padding: number[];
    private constructor();
    static fromArgs(args: EscrowConstraintModelArgs): EscrowConstraintModel;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [EscrowConstraintModel, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey, commitmentOrConfig?: web3.Commitment | web3.GetAccountInfoConfig): Promise<EscrowConstraintModel>;
    static gpaBuilder(programId?: web3.PublicKey): beetSolana.GpaBuilder<EscrowConstraintModelArgs>;
    static deserialize(buf: Buffer, offset?: number): [EscrowConstraintModel, number];
    serialize(): [Buffer, number];
    static byteSize(args: EscrowConstraintModelArgs): number;
    static getMinimumBalanceForRentExemption(args: EscrowConstraintModelArgs, connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    pretty(): {
        key: string;
        creator: string;
        name: string;
        constraints: Map<string, EscrowConstraint>;
        updateAuthority: string;
        count: number | {
            toNumber: () => number;
        };
        schemaUri: string;
        royalties: Map<RoyaltyInstruction, Partial<beet.bignum>>;
        royaltyBalance: number | {
            toNumber: () => number;
        };
        padding: number[];
    };
}
export declare const escrowConstraintModelBeet: beet.FixableBeetStruct<EscrowConstraintModel, EscrowConstraintModelArgs>;
